diff src/org/tmatesoft/hg/core/HgLogCommand.java @ 367:2fadf8695f8a

Use 'revision index' instead of the vague 'local revision number' concept in the API
author Artem Tikhomirov <tikhomirov.artem@gmail.com>
date Fri, 16 Dec 2011 15:37:27 +0100
parents 189dc6dc1c3e
children 8107b95f4280
line wrap: on
line diff
--- a/src/org/tmatesoft/hg/core/HgLogCommand.java	Fri Dec 16 04:43:18 2011 +0100
+++ b/src/org/tmatesoft/hg/core/HgLogCommand.java	Fri Dec 16 15:37:27 2011 +0100
@@ -132,8 +132,8 @@
 	/**
 	 * Limit to specified subset of Changelog, [min(rev1,rev2), max(rev1,rev2)], inclusive.
 	 * Revision may be specified with {@link HgRepository#TIP}  
 	 * @param rev1 - local revision number
 	 * @param rev2 - local revision number
 	 * @return <code>this</code> instance for convenience
 	 */
 	public HgLogCommand range(int rev1, int rev2) {
@@ -160,7 +160,7 @@
 	 */
 	public HgLogCommand changeset(Nodeid nid) throws HgInvalidControlFileException, HgInvalidRevisionException {
 		// XXX perhaps, shall support multiple (...) arguments and extend #execute to handle not only range, but also set of revisions.
-		final int csetLocal = repo.getChangelog().getLocalRevision(nid);
+		final int csetLocal = repo.getChangelog().getRevisionIndex(nid);
 		return range(csetLocal, csetLocal);
 	}
@@ -132,8 +132,8 @@
 	 * Limit to specified subset of Changelog, [min(rev1,rev2), max(rev1,rev2)], inclusive.
 	 * Revision may be specified with {@link HgRepository#TIP}  
-	 * @param rev1 - local revision number
-	 * @param rev2 - local revision number
+	 * @param rev1 - local revision index
+	 * @param rev2 - local revision index
 	 * @return <code>this</code> instance for convenience
 	 */